@@ -21,8 +21,7 @@ import os
 import sys
 import calculate.contrib
 from suds.transport.http import HttpTransport
-import httplib.client #http.client in python3
-from httplib.client import HTTPConnection
+from http.client import HTTPConnection, HTTPSConnection
 import socket
 import ssl
 import hashlib
@@ -59,7 +58,7 @@ class Client_suds(Client):
             os.makedirs(self.CRL_PATH)
 
 
-class clientHTTPSConnection(httplib.HTTPSConnection):
+class clientHTTPSConnection(HTTPSConnection):
     def __init__(self, host, port=None, key_file=None, cert_file=None,
                  strict=None, timeout=socket._GLOBAL_DEFAULT_TIMEOUT,
                  source_address=None, cert_path=None):
@@ -162,8 +161,8 @@ class clientHTTPSConnection(httplib.HTTPSConnection):
                     OpenSSL.SSL.FILETYPE_PEM, cert)
                 Issuer = certobj.get_issuer().get_components()
                 for item in Issuer:
-                    if item[0] == 'CN':
-                        filename = item[1]
+                    if item[0] == b'CN':
+                        filename = item[1].decode("UTF-8")
 
                 fc = open(root_cert_md5, "a")
                 fc.write('%s %s\n' % (md5sum, filename))
