@@ -17,7 +17,7 @@
 
 import sys
 import re
-from calculate.core.server.core_interfaces import MethodsInterface
+from .server.core_interfaces import MethodsInterface
 
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 
@@ -34,10 +34,8 @@ class Variables(MethodsInterface):
         Write variable to env files, or delete from env files
         """
         dv = self.clVars
-        data = filter(lambda x: x[LOCATION] or
-                                not x[LOCATION] and
-                                dv.isFromIni(x[VARIABLE].rpartition('.')[2]),
-                      vardata)
+        data = [x for x in vardata 
+            if x[LOCATION] or not x[LOCATION] and dv.isFromIni(x[VARIABLE])]
         if data:
             head = [_("Variable"), _("Mode"), _("Location"), _("Value")]
             self.printTable(_("List of variables"), head, data)
@@ -93,7 +91,7 @@ class Variables(MethodsInterface):
             else:
                 self.printDefault(removeQuotes(prevVal))
             return True
-        filter_names = {'all': None,
+        filter_names = {'all': lambda x: x,
                         'userset': lambda x: x[LOCATION],
                         'writable': lambda x: x[MODE].startswith("w"),
                         'system': lambda x: x[LOCATION] == "system",
@@ -101,7 +99,7 @@ class Variables(MethodsInterface):
                         'remote': lambda x: x[LOCATION] == "remote"}
         filterFunc = filter_names.get(filterVal,
                                       lambda x: filterVal in x[VARIABLE])
-        body = filter(filterFunc, vardata)
+        body = [x for x in vardata if filterFunc(x)]
         dv.close()
         if body:
             head = [_("Variable"), _("Mode"),
